@@ -16,13 +16,13 @@
 #' }
 docklets_create <- function(names = NULL,
                            size = getOption("do_size", "s-1vcpu-2gb"),
-                           region = getOption("do_region", "sfo1"),
+                           region = getOption("do_region", "sfo2"),
                            ssh_keys = getOption("do_ssh_keys", NULL),
                            backups = getOption("do_backups", NULL),
                            ipv6 = getOption("do_ipv6", NULL),
                            private_networking =
                              getOption("do_private_networking", NULL),
-                           tags = NULL,
+                           tags = list(),
                            wait = TRUE,
                            image = "docker-18-04",
                            ...) {
